@@ -1,6 +1,6 @@
 /*
 fullquottel - a program that helps to distinguish whether an email has the "tofu" style.
-Copyright (C) 2005-2012 Toastfreeware <toast@toastfreeware.priv.at> - 
+Copyright (C) 2005-2021 Toastfreeware <toast@toastfreeware.priv.at> - 
 Philipp Spitzer and Gregor Herrmann
 
 This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */                                                    
 
 
@@ -157,7 +157,7 @@ typedef multimap<string, string> MultiMap;
 // Command line parsing
 // --------------------
 
-const char *argp_program_version = "fullquottel 0.1.4";
+const char *argp_program_version = "fullquottel 0.1.5";
 const char *argp_program_bug_address = "<toast@toastfreeware.priv.at>";
 static char doc[] = "fullquottel - tool for detecting full quotes in mails or postings";
 static char args_doc[] = "< infile > outfile";
@@ -255,9 +255,9 @@ struct Options {
 		quoteChars = ">|#";
 		debug = false;
 		// should we keep the following?
-		attributionLines.push_back("-----Ursprngliche Nachricht-----");
+		attributionLines.push_back("-----Ursprüngliche Nachricht-----");
 		attributionLines.push_back("-----Original Message-----");
-		attributionLines.push_back("----- Ursprngliche Nachricht -----");
+		attributionLines.push_back("----- Ursprüngliche Nachricht -----");
 		attributionLines.push_back("----- Original Message -----");
 		// ratings
 		ownSigTest.file = "~/.signature";
@@ -436,7 +436,7 @@ TextLines loadTextLines(istream& istr) {
 /// Loads a key=value file (lines starting with # or empty lines are ignored)
 /// Multiple values for one key are allowed
 /// If an syntax error occurs, an exception is thrown.
-MultiMap multiMapFromTextLines(const TextLines& lines) throw(runtime_error) {
+MultiMap multiMapFromTextLines(const TextLines& lines) {
 	MultiMap mm;
 	for (unsigned i = 0; i != lines.size(); ++i) {
 		string line = trim(lines[i]);
